@@ -1,6 +1,6 @@
 #  MIT License
 #
-#  Copyright (c) 2017-2022 TileDB Inc.
+#  Copyright (c) 2017-2023 TileDB Inc.
 #
 #  Permission is hereby granted, free of charge, to any person obtaining a copy
 #  of this software and associated documentation files (the "Software"), to deal
@@ -606,7 +606,7 @@ setMethod("[", "tiledb_array",
 
   ## helper function to sweep over names and types of domain
   getDomain <- function(nm, tp) {
-    if (tp %in% c("ASCII", "CHAR")) {
+    if (tp %in% c("ASCII", "CHAR", "UTF8")) {
       libtiledb_array_get_non_empty_domain_var_from_name(arrptr, nm)
     } else {
       libtiledb_array_get_non_empty_domain_from_name(arrptr, nm, tp)
@@ -708,50 +708,57 @@ setMethod("[", "tiledb_array",
   }
   ## (i,j,k) are now done and transferred to x@select_ranges
 
+  ## pointer to subarray needed for iterated setting of points from selected_ranges
+  ## and selected_points across all possible dimensions
+  have_made_selection <- FALSE
+  sbrptr <- libtiledb_subarray(qryptr)
 
   ## if ranges selected, use those
   for (k in seq_len(length(x@selected_ranges))) {
-    if (is.null(x@selected_ranges[[k]]) && is.null(x@selected_points[[k]])) {
-      #cat("Adding null dim", k, "on", dimtypes[k], "\n")
-      vec <- .map2integer64(nonemptydom[[k]], dimtypes[k])
-      if (vec[1] != 0 || vec[2] != 0) { # corner case of A[] on empty array
-        qryptr <- libtiledb_query_add_range_with_type(qryptr, k-1, dimtypes[k], vec[1], vec[2])
-        spdl::debug("[tiledb_array] Adding non-zero dim {}:{} on {} with ({},{})", k, i, dimtypes[k], vec[1], vec[2])
-        rangeunset <- FALSE
+      if (is.null(x@selected_ranges[[k]]) && is.null(x@selected_points[[k]])) {
+          vec <- .map2integer64(nonemptydom[[k]], dimtypes[k])
+          if (vec[1] != 0 || vec[2] != 0) { # corner case of A[] on empty array
+              sbrptr <- libtiledb_subarray_add_range_with_type(sbrptr, k-1, dimtypes[k], vec[1], vec[2])
+              spdl::debug("[tiledb_array] Adding non-zero dim {}:{} on {} with ({},{})", k, i, dimtypes[k], vec[1], vec[2])
+              rangeunset <- FALSE
+              have_made_selection <- TRUE
+          }
+      } else if (is.null(nrow(x@selected_ranges[[k]])) && is.null(x@selected_points[[k]])) {
+          vec <- x@selected_ranges[[k]]
+          vec <- .map2integer64(vec, dimtypes[k])
+          sbrptr <- libtiledb_subarray_add_range_with_type(sbrptr, k-1, dimtypes[k], min(vec), max(vec))
+          spdl::debug("[tiledb_array] Adding non-zero dim {}:{} on {} with ({},{})", k, i, dimtypes[k], vec[1], vec[2])
+          rangeunset <- FALSE
+          have_made_selection <- TRUE
+      } else if (is.null(x@selected_points[[k]])) {
+          m <- x@selected_ranges[[k]]
+          for (i in seq_len(nrow(m))) {
+              vec <- .map2integer64(c(m[i,1], m[i,2]), dimtypes[k])
+              sbrptr <- libtiledb_subarray_add_range_with_type(sbrptr, k-1, dimtypes[k], vec[1], vec[2])
+              spdl::debug("[tiledb_array] Adding non-zero dim {}:{} on {} with ({},{})", k, i, dimtypes[k], vec[1], vec[2])
+          }
+          rangeunset <- FALSE
+          have_made_selection <- TRUE
       }
-    } else if (is.null(nrow(x@selected_ranges[[k]])) && is.null(x@selected_points[[k]])) {
-      #cat("Adding nrow null dim", k, "on", dimtypes[k], "\n")
-      vec <- x@selected_ranges[[k]]
-      vec <- .map2integer64(vec, dimtypes[k])
-      qryptr <- libtiledb_query_add_range_with_type(qryptr, k-1, dimtypes[k], min(vec), max(vec))
-      spdl::debug("[tiledb_array] Adding non-zero dim {}:{} on {} with ({},{})", k, i, dimtypes[k], vec[1], vec[2])
-      rangeunset <- FALSE
-    } else if (is.null(x@selected_points[[k]])) {
-      #cat("Adding non-zero dim", k, "on", dimtypes[k], "\n")
-      m <- x@selected_ranges[[k]]
-      for (i in seq_len(nrow(m))) {
-        vec <- .map2integer64(c(m[i,1], m[i,2]), dimtypes[k])
-        qryptr <- libtiledb_query_add_range_with_type(qryptr, k-1, dimtypes[k], vec[1], vec[2])
-        spdl::debug("[tiledb_array] Adding non-zero dim {}:{} on {} with ({},{})", k, i, dimtypes[k], vec[1], vec[2])
-      }
-      rangeunset <- FALSE
-    }
   }
 
   ## if points selected, use those (and fewer special cases as A[i,j,k] not folded into points)
   for (k in seq_len(length(x@selected_points))) {
-    if (!is.null(x@selected_points[[k]])) {
-      spdl::debug("[tiledb_array] Adding non-zero dim {} on {}", k, dimtypes[k])
-      m <- x@selected_points[[k]]
-      for (i in seq_along(m)) {
-        vec <- .map2integer64(c(m[i], m[i]), dimtypes[k])
-        qryptr <- libtiledb_query_add_range_with_type(qryptr, k-1, dimtypes[k], vec[1], vec[2])
-        spdl::debug("[tiledb_array] Adding point on non-zero dim {}:{} on {} with ({},{})", k, i, dimtypes[k], vec[1], vec[2])
+      if (!is.null(x@selected_points[[k]])) {
+          m <- x@selected_points[[k]]
+          for (i in seq_along(m)) {
+              vec <- .map2integer64(c(m[i], m[i]), dimtypes[k])
+              sbrptr <- libtiledb_subarray_add_range_with_type(sbrptr, k-1, dimtypes[k], vec[1], vec[2])
+              spdl::debug("[tiledb_array] Adding point on non-zero dim {}:{} on {} with ({},{})", k, i, dimtypes[k], vec[1], vec[2])
+          }
+          rangeunset <- FALSE
+          have_made_selection <- TRUE
       }
-      rangeunset <- FALSE
-    }
   }
 
+  if (have_made_selection)
+      libtiledb_query_set_subarray_object(qryptr, sbrptr)
+
   buflist <- vector(mode="list", length=length(allnames))
 
   if (length(x@buffers) != 0) {         # if we were given buffers (as in the case of TileDB Cloud ops)
@@ -829,6 +836,7 @@ setMethod("[", "tiledb_array",
               if (type %in% c("CHAR", "ASCII", "UTF8")) {
                   spdl::debug("[getBuffer] '{}' allocating 'char' {} rows given budget of {}", name, resrv, memory_budget)
                   buf <- libtiledb_query_buffer_var_char_alloc_direct(resrv, memory_budget, nullable)
+                  buf <- libtiledb_query_buffer_var_char_legacy_validity_mode(ctx@ptr, buf)
                   qryptr <- libtiledb_query_set_buffer_var_char(qryptr, name, buf)
                   buf
               } else {
@@ -874,19 +882,21 @@ setMethod("[", "tiledb_array",
 
           ## retrieve actual result size (from fixed size element columns)
           getResultSize <- function(name, varnum, qryptr) {
-              if (is.na(varnum))                  # symbols come up with higher count
-                  libtiledb_query_result_buffer_elements(qryptr, name, 0)
-              else
-                  libtiledb_query_result_buffer_elements(qryptr, name)
+              val <- if (is.na(varnum))                  # symbols come up with higher count
+                         libtiledb_query_result_buffer_elements(qryptr, name, 0)
+                     else
+                         libtiledb_query_result_buffer_elements(qryptr, name)
+              spdl::debug("[getResultSize] name {} varnum {} has {}", name, varnum, val)
+              val
           }
           estsz <- mapply(getResultSize, allnames, allvarnum, MoreArgs=list(qryptr=qryptr), SIMPLIFY=TRUE)
-          spdl::debug("['['] estimated result sizes", paste(estsz, collapse=","))
+          spdl::debug("['['] estimated result sizes {}", paste(estsz, collapse=","))
           if (any(!is.na(estsz))) {
               resrv <- max(estsz, na.rm=TRUE)
           } else {
-              resrv <- resrv/8                  # character case where bytesize of offset vector was used
+              resrv <- resrv/8              # character case where bytesize of offset vector was used
           }
-          spdl::debug("['['] expected size", resrv)
+          spdl::debug("['['] expected size {}", resrv)
           ## Permit one pass to allow zero-row schema read
           if (resrv == 0 && counter > 1L) {
               finished <- TRUE
@@ -1233,14 +1243,15 @@ setMethod("[<-", "tiledb_array",
                                          else { if (sparse) "UNORDERED" else "COL_MAJOR" })
 
     buflist <- vector(mode="list", length=nc)
+    legacy_validity <- libtiledb_query_buffer_var_char_get_legacy_validity_value(ctx@ptr)
 
     for (colnam in allnames) {
       ## when an index column is use this may be unordered to remap to position in 'nm' names
       k <- match(colnam, nm)
-      if (alltypes[k] %in% c("CHAR", "ASCII")) { # variable length
+      if (alltypes[k] %in% c("CHAR", "ASCII", "UTF8")) { # variable length
         txtvec <- as.character(value[[k]])
         spdl::debug("[tiledb_array] '[<-' alloc char buffer {} '{}': {}", k, colnam, alltypes[k])
-        buflist[[k]] <- libtiledb_query_buffer_var_char_create(txtvec, allnullable[k])
+        buflist[[k]] <- libtiledb_query_buffer_var_char_create(txtvec, allnullable[k], legacy_validity)
         qryptr <- libtiledb_query_set_buffer_var_char(qryptr, colnam, buflist[[k]])
       } else {
         col <- value[[k]]
