@@ -61,17 +61,6 @@ ctx <- tiledb_get_context()
 expect_true(is(ctx@ptr, "externalptr"))
 #})
 
-#test_that("default libtiledb_ctx config is the default config", {
-if (FALSE) {
-  # does not hold now that we set the config at run-time to throttle threads
-  ctx <- tiledb_get_context()
-  ctx_config <- tiledb:::libtiledb_ctx_config(ctx@ptr)
-  default_config <- tiledb:::libtiledb_config()
-  expect_equal(tiledb:::libtiledb_config_vector(ctx_config),
-               tiledb:::libtiledb_config_vector(default_config))
-}
-#}
-
 #test_that("libtiledb_ctx with config", {
 config <- tiledb:::libtiledb_config(c(foo = "bar"))
 ctx <- tiledb:::libtiledb_ctx(config)
@@ -118,12 +107,8 @@ expect_true(is(dom, "externalptr"))
 ctx <- tiledb_get_context()@ptr
 d1 <- tiledb:::libtiledb_dim(ctx, "d1", "INT32", c(1L, 100L), 10L)
 d2 <- tiledb:::libtiledb_dim(ctx, "d2", "FLOAT64", c(1, 100), 10)
-if (tiledb_version(compact=TRUE) < as.package_version("1.8.0")) {
-  expect_error(tiledb:::libtiledb_domain(ctx, c(d1, d2)))
-} else {
-  dom <- tiledb:::libtiledb_domain(ctx, c(d1, d2))
-  expect_true(is(dom, "externalptr"))
-}
+dom <- tiledb:::libtiledb_domain(ctx, c(d1, d2))
+expect_true(is(dom, "externalptr"))
 #})
 
 #test_that("basic integer libtiledb_attr constructor works", {
@@ -224,6 +209,7 @@ qry <- tiledb:::libtiledb_query_set_buffer(qry, "a1", dat)
 qry <- tiledb:::libtiledb_query_submit(qry)
 tiledb:::libtiledb_array_close(arr)
 expect_true(is(qry, "externalptr"))
+if (tiledb_version(TRUE) < "2.7.0") exit_file("Needs TileDB 2.7.* or later")
 
 res <- c(0, 0)
 sub <- c(1L, 2L)
